/* -*- c++ -*- */
/*
 * Copyright 2002 Free Software Foundation, Inc.
 * 
 * This file is part of GNU Radio
 * 
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 * 
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef _ATSCFAKESINGLEVITERBI_H_
#define _ATSCFAKESINGLEVITERBI_H_

#include <atsc_api.h>

/*!
 * \brief single channel viterbi decoder
 */
class ATSC_API atsci_fake_single_viterbi
{
  
public:
  atsci_fake_single_viterbi ();

  /*!
   * \p INPUT ideally takes on the values +/- 1,3,5,7
   * return is decoded dibit in the range [0, 3]
   */
  char decode (float input);

  void reset ();

  //! internal delay of decoder
  int delay () { return 0; }

protected:
  int	post_coder_state;
};

#endif 
